Setup-data-libraries
=====================

.. automodule :: ephemeris.setup_data_libraries

Usage
----------

.. argparse::
   :module: ephemeris.setup_data_libraries
   :func: _parser
   :prog: setup-data-libraries
